require File.expand_path('spec/spec_helper')
require "rampart/events/redirect_event"

describe Rampart::RedirectEvent do
  describe "::new" do
    it "receives url parameter" do
      event = Rampart::RedirectEvent.new("http://www.kodio.io")
      status, headers, body = event.to_truple
      _(headers["Location"]).must_equal("http://www.kodio.io")
    end

    it "receives optional status parameter" do
      event = Rampart::RedirectEvent.new("http://www.kodio.io", 302)
      status, headers, body = event.to_truple
      _(status).must_equal(302)
    end

    it "defaults status to 302" do
      event = Rampart::RedirectEvent.new("http://www.kodio.io")
      status, headers, body = event.to_truple
      _(status).must_equal(302)
    end
  end

  it "halts" do
    event = Rampart::RedirectEvent.new("http://www.kodio.io")
    _(event.halt?).must_equal(true)
  end

  it "isn't successful" do
    event = Rampart::RedirectEvent.new("http://www.kodio.io")
    _(event.success?).must_equal(false)
  end

  it "can return rack truple" do
    event = Rampart::RedirectEvent.new("http://www.kodio.io", 301)
    status, headers, body = event.to_truple
    
    _(status).must_equal(301)
    _(headers).must_equal({"Content-Length"=>"35", "Location"=>"http://www.kodio.io"})
    _(body).must_equal(["Redirecting to: http://www.kodio.io"])
  end
end